@@ -6,6 +6,7 @@ import urlparse
 import inspect
 import email.utils as eut
 from datetime import datetime
+from ujson import dumps
 
 import codecs
 from box.util.rotunicode import RotUnicode
@@ -62,7 +63,7 @@ class ReviewDAO(object):
 
 class Reviewer(object):
     def __init__(
-            self, api_url, page_uuid, page_url, page_score, ping_method=None,
+            self, api_url, page_uuid, page_url, page_score,
             increase_lambda_tax_method=None, config=None, validators=[], facters=[],
             async_get=None, wait=None, wait_timeout=None, db=None, cache=None, publish=None,
             fact_definitions=None, violation_definitions=None):
@@ -77,7 +78,7 @@ class Reviewer(object):
         self.page_url = page_url
         self.page_score = page_score
 
-        self.ping_method = ping_method
+        self.ping_method = None
         self.increase_lambda_tax_method = increase_lambda_tax_method
 
         self.review_dao = ReviewDAO(self.page_uuid, self.page_url)
@@ -127,6 +128,9 @@ class Reviewer(object):
         return handle
 
     def save_request(self, url, response):
+        if not response:
+            return
+
         request_time = response.request_time
         effective_url = response.effective_url
         status_code = response.status_code
@@ -147,6 +151,13 @@ class Reviewer(object):
 
         self.db.add(req)
 
+        self.cache.increment_requests_count()
+
+        self.publish(dumps({
+            'type': 'new-request',
+            'url': str(url)
+        }))
+
     def review(self):
         self.load_content(self.content_loaded)
         self.wait_for_async_requests()
